@@ -18,8 +18,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module HVIOtest(tests) where
 import Test.HUnit
-import MissingH.IO.HVIO
-import MissingH.HUnit
+import System.IO.HVIO
+import Test.HUnit.Utils
 import System.IO
 import System.IO.Error
 import Control.Exception
